@@ -1,24 +1,53 @@
-import logging
+# Copyright (C) 2019-2021 Clémence Frioux & Arnaud Belcour - Inria Dyliss - Pleiade
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>
+
 import argparse
 import logging
 import os
 import pkg_resources
 import re
+import subprocess
 import sys
 import tarfile
 import time
 import traceback
-import subprocess
-from shutil import copyfile,which
 
-from metage2metabo.m2m_workflow import run_workflow, recon, iscope, cscope, addedvalue, mincom, instance_community, metacom_analysis
+from shutil import which
+
+from metage2metabo.m2m.reconstruction import recon
+from metage2metabo.m2m.individual_scope import iscope
+from metage2metabo.m2m.community_scope import cscope, instance_community
+from metage2metabo.m2m.community_addedvalue import addedvalue
+from metage2metabo.m2m.minimal_community import mincom
+from metage2metabo.m2m.m2m_workflow import run_workflow, metacom_analysis
+
 from metage2metabo import sbml_management, utils
 
 VERSION = pkg_resources.get_distribution("metage2metabo").version
-LICENSE = """Copyright (C) Dyliss
-License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>
-metage2metabo is free software: you are free to change and redistribute it.
-There is NO WARRANTY, to the extent permitted by law.\n
+LICENSE = """Copyright (C) Dyliss & Pleiade\n
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU Lesser General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.\n
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU Lesser General Public License for more details.\n
+
+You should have received a copy of the GNU Lesser General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>\n
 """
 MESSAGE = """
 From metabolic network reconstruction with annotated genomes to metabolic capabilities screening to identify organisms of interest in a large microbiota.
@@ -75,7 +104,7 @@ def main():
     parent_parser_c.add_argument(
         "-c",
         "--cpu",
-        help="cpu number for multi-process",
+        help="cpu number for multiprocessing",
         required=False,
         type=int,
         default=1)
@@ -96,6 +125,15 @@ def main():
         action="store_true",
         default=False,
     )
+    parent_parser_xml = argparse.ArgumentParser(add_help=False)
+    parent_parser_xml.add_argument(
+        "--pwt-xml",
+        dest="pwt_xml",
+        help="use this option to use Pathway Tools xml (incompatible with -p)",
+        required=False,
+        action="store_true",
+        default=False,
+    )
     parent_parser_s = argparse.ArgumentParser(add_help=False)
     parent_parser_s.add_argument(
         "-s",
@@ -168,7 +206,8 @@ def main():
         help="metabolic network reconstruction",
         parents=[
             parent_parser_g, parent_parser_o, parent_parser_c, parent_parser_q,
-            parent_parser_l, parent_parser_no, parent_parser_p, parent_parser_cl
+            parent_parser_l, parent_parser_no, parent_parser_p, parent_parser_cl,
+            parent_parser_xml
         ],
         description=
         "Run metabolic network reconstruction for each annotated genome of the input directory, using Pathway Tools"
@@ -177,7 +216,7 @@ def main():
         "iscope",
         help="individual scope computation",
         parents=[
-            parent_parser_n, parent_parser_s, parent_parser_o, parent_parser_q
+            parent_parser_n, parent_parser_s, parent_parser_o, parent_parser_q, parent_parser_c
         ],
         description=
         "Compute individual scopes (reachable metabolites from seeds) for each metabolic network of the input directory"
@@ -227,7 +266,7 @@ def main():
         parents=[
             parent_parser_g, parent_parser_s, parent_parser_m, parent_parser_o,
             parent_parser_c, parent_parser_q, parent_parser_no, parent_parser_p,
-            parent_parser_t_optional, parent_parser_cl
+            parent_parser_t_optional, parent_parser_cl, parent_parser_xml
         ],
         description=
         "Run the whole workflow: metabolic network reconstruction, individual and community scope analysis and community selection"
@@ -237,7 +276,7 @@ def main():
         help="whole metabolism community analysis",
         parents=[
             parent_parser_n, parent_parser_s, parent_parser_m, parent_parser_o,
-            parent_parser_t_optional, parent_parser_q
+            parent_parser_t_optional, parent_parser_q, parent_parser_c
         ],
         description=
         "Run the whole metabolism community analysis: individual and community scope analysis and community selection"
@@ -268,8 +307,6 @@ def main():
         parser.print_help()
         sys.exit()
 
-    # logger = logging.getLogger()    #TODO: get rid of it once mpwt's logger is fixed
-    # logger.setLevel(logging.DEBUG)  #TODO: get rid of it once mpwt's logger is fixed
     # add logger in file
     formatter = logging.Formatter('%(message)s')
     log_file_path = os.path.join(args.out, f'm2m_{args.cmd}.log')
@@ -292,6 +329,11 @@ def main():
     else:
         new_arg_modelhost = None
 
+    if args.cmd in ["workflow", "recon"]:
+        if args.pwt_xml and args.padmet:
+            logger.critical("-p and --pwt-xml are incompatible arguments")
+            sys.exit(1)
+
     if "seeds" in args and args.seeds is not None:
         if not utils.is_valid_file(args.seeds):
             logger.critical(args.seeds + " is not a correct filepath")
@@ -300,7 +342,7 @@ def main():
     # deal with given subcommand
     if args.cmd == "workflow":
         main_workflow(args.genomes, args.out, args.cpu, args.clean, args.seeds,
-                      args.noorphan, args.padmet, new_arg_modelhost, args.targets)
+                      args.noorphan, args.padmet, new_arg_modelhost, args.targets, args.pwt_xml)
     elif args.cmd in ["iscope", "cscope", "addedvalue", "mincom", "metacom"]:
         if not os.path.isdir(args.networksdir):
             logger.critical(args.networksdir + " is not a correct directory path")
@@ -313,9 +355,9 @@ def main():
             # test if some targets are seeds
             itsct_seeds_targets = sbml_management.compare_seeds_and_targets(args.seeds, args.targets)
             if itsct_seeds_targets != set():
-                logger.warning(f"\nWARNING: compounds {*list(itsct_seeds_targets),} are both in seeds and targets. Since they are in seeds, they will be in each organism's individual producibility scope (iscope), but not appear in the community scope (cscope). To be certain that they are produced (through an activable reaction and not just because they are seeds), check the output file: producibility_targets.json.\n")
+                logger.warning(f"\nWARNING: compounds {*list(itsct_seeds_targets),} are both in seeds and targets. Since they are in seeds, they will be in each organism's individual producibility scope (iscope), but not appear in the community scope (cscope). To be certain that they are produced (through an activable reaction and not just because they are seeds), check the output file: indiv_scopes/indiv_produced_seeds.json and the key 'individually producible' in the file producibility_targets.json.\n")
         if args.cmd == "iscope":
-            main_iscope(network_dir, args.seeds, args.out)
+            main_iscope(network_dir, args.seeds, args.out, args.cpu)
         elif args.cmd == "cscope":
             main_cscope(network_dir, args.seeds, args.out, args.targets, new_arg_modelhost)
         elif args.cmd == "addedvalue":
@@ -324,10 +366,10 @@ def main():
         elif args.cmd == "mincom":
             main_mincom(network_dir, args.seeds, args.out, args.targets, new_arg_modelhost)
         elif args.cmd == "metacom":
-            main_metacom(network_dir, args.out, args.seeds, new_arg_modelhost, args.targets)
+            main_metacom(network_dir, args.out, args.seeds, new_arg_modelhost, args.targets, args.cpu)
     elif args.cmd == "recon":
         main_recon(args.genomes, args.out, args.noorphan, args.padmet, args.level, args.cpu,
-                   args.clean)
+                   args.clean, args.pwt_xml)
     elif args.cmd == "seeds":
         if not utils.is_valid_file(args.metabolites):
             logger.critical(args.metabolites + " is not a correct filepath")
@@ -358,7 +400,7 @@ def main_recon(*allargs):
     """
     pgdbdir, sbmldir, padmet_folder= recon(*allargs)
     logger.info("PGDB created in " + pgdbdir)
-    if allargs[3]:
+    if allargs[3] and padmet_folder:
         logger.info("PADMET files created in " + padmet_folder)
 
     logger.info("SBML files created in " + sbmldir)
@@ -471,10 +513,12 @@ def main_test(outdir, cpu):
     padmet_bool=True
     host_mn=None
     targets_file=None
+    use_pwt_xml=False
     main_workflow(inp_dir, out_dir, nb_cpu,
                 clean, seeds, noorphan_bool,
-                padmet_bool, host_mn, targets_file)
+                padmet_bool, host_mn, targets_file,
+                use_pwt_xml)
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
