@@ -1,3 +1,17 @@
+# Copyright (C) 2019-2021 Clémence Frioux & Arnaud Belcour - Inria Dyliss - Pleiade
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>
+
 import libsbml
 import logging
 import os
@@ -13,19 +27,23 @@ logger = logging.getLogger(__name__)
 
 
 def get_compounds(sbml_file):
-    """Get target from sbml
+    """Get compound from sbml
 
     Args:
         sbml_file (str): SBML file
 
     Returns:
-        list: target
+        list: compound
     """
     reader = SBMLReader()
     document = reader.readSBML(sbml_file)
     model = document.getModel()
-    targets = [target.id for target in model.getListOfSpecies()]
-    return targets
+    if model is None:
+        logger.critical('SBML file "' + sbml_file + '" not well formatted. Is this file a SBML? Does it contains <model></model> tags?')
+        sys.exit(1)
+    compounds = [compound.id for compound in model.getListOfSpecies()]
+    return compounds
+
 
 def compare_seeds_and_targets(seedfile, targetfile):
     """Returns the intersection of the seeds and the targets
@@ -109,6 +127,7 @@ def pgdb_to_sbml(pgdb_dir, output_dir, noorphan_bool, padmet_bool, sbml_level, c
         pgdb_dir (str): PGDB directory
         output_dir (str): results directory
         noorphan_bool (bool): ignores orphan reactions if True
+        padmet_bool (bool): creates padmet files if True
         sbml_level (int): SBML level
         cpu (int): number of CPU for multi-process
     
@@ -118,9 +137,9 @@ def pgdb_to_sbml(pgdb_dir, output_dir, noorphan_bool, padmet_bool, sbml_level, c
 
     logger.info('######### Creating SBML files #########')
     sbml_dir = os.path.join(output_dir, 'sbml')
+    padmet_dir = os.path.join(output_dir, 'padmet')
 
     if padmet_bool:
-        padmet_dir = os.path.join(output_dir, 'padmet')
         if not utils.is_valid_dir(padmet_dir):
             logger.critical('Impossible to access/create output directory')
             sys.exit(1)
