@@ -236,8 +236,8 @@ def test_m2m_metacom_targets_import():
         os.makedirs(respath)
     with tarfile.open(toy_bact_tgz_path) as tar:
         tar.extractall(path=respath)
-    metage2metabo.m2m_workflow.metacom_analysis(sbml_dir=toy_bact_path, out_dir=respath,
-                seeds=seeds_path, host_mn=None, targets_file=targets_path)
+    metage2metabo.m2m.m2m_workflow.metacom_analysis(sbml_dir=toy_bact_path, out_dir=respath,
+                seeds=seeds_path, host_mn=None, targets_file=targets_path, cpu_number=1)
 
     iscope_file = os.path.join(*[respath, 'indiv_scopes', 'indiv_scopes.json'])
     cscope_file = os.path.join(*[respath, 'community_analysis', 'comm_scopes.json'])
@@ -276,7 +276,7 @@ def test_m2m_metacom_targets_import():
     # ensure the newly producible targets are ok
     assert set(d_mincom['producible']) == PROD_TARGETS
     # ensure the bacteria in union are ok
-    assert set(d_target['keystone_species']) == UNION
+    assert set(d_target['key_species']) == UNION
     # ensure the newly producible targets are ok
     assert set(d_target['mincom_producible']) == PROD_TARGETS
 
@@ -289,6 +289,8 @@ def test_m2m_metacom_targets_import():
         model = document.getModel()
         sbml_name, _ = os.path.splitext(sbml_file)
         sbml_products[sbml_name] = [product.getSpecies() for sbml_reaction in model.getListOfReactions() for product in sbml_reaction.getListOfProducts()]
+        sbml_products[sbml_name].extend([reactant.getSpecies() for sbml_reaction in model.getListOfReactions() if sbml_reaction.reversible == True for reactant in sbml_reaction.getListOfReactants()])
+        sbml_products[sbml_name] = set(sbml_products[sbml_name])
 
     for target in d_target['com_only_producers']:
         for species in d_target['com_only_producers'][target]:
@@ -297,6 +299,45 @@ def test_m2m_metacom_targets_import():
     shutil.rmtree(respath)
 
 
+def test_metacom_produced_seed():
+    inppath = 'metabolic_data/'
+    respath = 'metacom_output/'
+    toy_bact_tgz_path = os.path.join(inppath, 'toy_bact.tar.gz')
+    toy_bact_path = os.path.join(respath, 'toy_bact')
+    seeds_path = os.path.join(inppath, 'seeds_toy.sbml')
+    target_txt_path = 'seed_butyrate.txt'
+    targets_path = os.path.join(respath, 'seeds.sbml')
+    targets_producibility = os.path.join(respath, 'producibility_targets.json')
+
+    expected_producers = ['GCA_003437905', 'GCA_003438055', 'GCA_003437885', 'GCA_003437815', 'GCA_003437595', 'GCA_003437375']
+    if not os.path.exists(respath):
+        os.makedirs(respath)
+    with tarfile.open(toy_bact_tgz_path) as tar:
+        tar.extractall(path=respath)
+
+    with open(target_txt_path, 'w') as butyrate_output:
+        butyrate_output.write('M_BUTYRIC_ACID_c')
+    subprocess.call([
+        'm2m', 'seeds', '--metabolites', target_txt_path, '-o', respath
+    ])
+
+    subprocess.call([
+        'm2m', 'metacom', '-n', toy_bact_path, '-o',
+        respath, '-s', seeds_path, '-t', targets_path,
+        '-q'
+    ])
+
+    with open(targets_producibility, 'r') as json_output:
+        d_producibility = json.load(json_output)
+
+    assert set(d_producibility['individual_producers']['M_BUTYRIC_ACID_c']) == set(expected_producers)
+
+    # clean
+    os.remove(target_txt_path)
+    shutil.rmtree(respath)
+
+
 if __name__ == "__main__":
     test_m2m_metacom_call()
-    test_m2m_metacom_targets_import()
\ No newline at end of file
+    test_m2m_metacom_targets_import()
+    test_metacom_produced_seed()
\ No newline at end of file
